@@ -14,6 +14,7 @@ from jsonpickle.compat import set
 
 
 class Thing(object):
+
     def __init__(self, name):
         self.name = name
         self.child = None
@@ -23,7 +24,9 @@ class Thing(object):
 
 
 class ThingWithSlots(object):
+
     __slots__ = ('a', 'b')
+
     def __init__(self, a, b):
         self.a = a
         self.b = b
@@ -76,14 +79,45 @@ class DictSubclass(dict):
     name = 'Test'
 
 
+class GetstateDict(dict):
+
+    def __init__(self, name, **kwargs):
+        dict.__init__(self, **kwargs)
+        self.name = name
+        self.active = False
+
+    def __getstate__(self):
+        return (self.name, dict(self.items()))
+
+    def __setstate__(self, state):
+        self.name, vals = state
+        self.update(vals)
+        self.active = True
+
+
 class ListSubclass(list):
     pass
 
 class ListSubclassWithInit(list):
+
     def __init__(self, attr):
         self.attr = attr
         super(ListSubclassWithInit, self).__init__()
 
+
+class GetstateReturnsList(object):
+
+    def __init__(self, x, y):
+        self.x = x
+        self.y = y
+
+    def __getstate__(self):
+        return [self.x, self.y]
+
+    def __setstate__(self, state):
+        self.x, self.y = state[0], state[1]
+
+
 class SetSubclass(set):
     pass
 
@@ -98,6 +132,7 @@ class BrokenReprThing(Thing):
 
 
 class Node(object):
+
     def __init__(self, name):
         self._name = name
         self._children = []
@@ -111,18 +146,18 @@ class Node(object):
 
 
 class Document(Node):
+
     def __init__(self, name):
         Node.__init__(self, name)
 
     def __str__(self):
-        ret_str ='Document "%s"\n' %self._name
+        ret_str ='Document "%s"\n' % self._name
         for c in self._children:
             ret_str += repr(c)
-
         return ret_str
 
     def __repr__(self):
-        return self.__str__()
+        return str(self)
 
 class Section(Node):
     def __init__(self, name):
