@@ -6,7 +6,6 @@
 #
 # This software is licensed as described in the file COPYING, which
 # you should have received as part of this distribution.
-import operator
 
 import jsonpickle.util as util
 import jsonpickle.tags as tags
@@ -52,10 +51,13 @@ class Pickler(object):
         self._max_depth = max_depth
         ## Maps id(obj) to reference IDs
         self._objs = {}
+        ## Avoids garbage collection
+        self._seen = []
 
     def reset(self):
         self._objs = {}
         self._depth = -1
+        self._seen = []
 
     def _push(self):
         """Steps down one level in the namespace.
@@ -120,7 +122,10 @@ class Pickler(object):
 
     def _flatten(self, obj):
         self._push()
+        return self._pop(self._flatten_obj(obj))
 
+    def _flatten_obj(self, obj):
+        self._seen.append(obj)
         max_reached = self._depth == self._max_depth
 
         if max_reached or (not self.make_refs and id(obj) in self._objs):
@@ -129,14 +134,17 @@ class Pickler(object):
         else:
             flatten_func = self._get_flattener(obj)
 
-        return self._pop(flatten_func(obj))
+        return flatten_func(obj)
+
+    def _list_recurse(self, obj):
+        return [self._flatten(v) for v in obj]
 
     def _get_flattener(self, obj):
 
         if util.is_primitive(obj):
             return lambda obj: obj
 
-        list_recurse = lambda obj: [self._flatten(v) for v in obj]
+        list_recurse = self._list_recurse
 
         if util.is_list(obj):
             if self._mkref(obj):
@@ -187,21 +195,20 @@ class Pickler(object):
         has_class = hasattr(obj, '__class__')
         has_dict = hasattr(obj, '__dict__')
         has_slots = not has_dict and hasattr(obj, '__slots__')
-        has_getstate = has_dict and hasattr(obj, '__getstate__')
-        has_getstate_support = has_getstate and hasattr(obj, '__setstate__')
 
-        HandlerClass = handlers.get(type(obj))
+        # Support objects with __getstate__(); this ensures that
+        # both __setstate__() and __getstate__() are implemented
+        has_getstate = hasattr(obj, '__getstate__')
+        has_getstate_support = has_getstate and hasattr(obj, '__setstate__')
 
         if has_class and not util.is_module(obj):
             module, name = _getclassdetail(obj)
             if self.unpicklable:
                 data[tags.OBJECT] = '%s.%s' % (module, name)
             # Check for a custom handler
-            if HandlerClass:
-                handler = HandlerClass(self)
-                flat_obj = handler.flatten(obj, data)
-                self._mkref(flat_obj)
-                return flat_obj
+            handler = handlers.get(type(obj))
+            if handler is not None:
+                return handler(self).flatten(obj, data)
 
         if util.is_module(obj):
             if self.unpicklable:
@@ -212,22 +219,18 @@ class Pickler(object):
             return data
 
         if util.is_dictionary_subclass(obj):
-            return self._flatten_dict_obj(obj, data)
+            self._flatten_dict_obj(obj, data)
+            if has_getstate_support:
+                self._getstate(obj, data)
+            return data
 
         if has_dict:
             # Support objects that subclasses list and set
             if util.is_sequence_subclass(obj):
                 return self._flatten_sequence_obj(obj, data)
 
-            # Support objects with __getstate__(); this ensures that
-            # both __setstate__() and __getstate__() are implemented
             if has_getstate_support:
-                state = self._flatten(obj.__getstate__())
-                if self.unpicklable:
-                    data[tags.STATE] = state
-                else:
-                    data = state
-                return data
+                return self._getstate(obj, data)
 
             # hack for zope persistent objects; this unghostifies the object
             getattr(obj, '_', None)
@@ -249,7 +252,7 @@ class Pickler(object):
             data = obj.__class__()
 
         flatten = self._flatten_key_value_pair
-        for k, v in sorted(obj.items(), key=operator.itemgetter(0)):
+        for k, v in sorted(obj.items(), key=util.itemgetter):
             flatten(k, v, data)
 
         # the collections.defaultdict protocol
@@ -294,6 +297,15 @@ class Pickler(object):
             return value
         return data
 
+    def _getstate(self, obj, data):
+        state = self._flatten_obj(obj.__getstate__())
+        if self.unpicklable:
+            data[tags.STATE] = state
+        else:
+            data = state
+        return data
+
+
 def _mktyperef(obj):
     """Return a typeref dictionary
 
